hubness.reduction API — hubness 0.21a1 documentation

# hubness.reduction API

## hubness.reduction Package

### Classes

`NoHubnessReduction` | Dummy class to test the library
`LocalScaling`([k, method, verbose]) | Hubness reduction with local scaling.
`MutualProximity`([k, method, verbose]) | Hubness reduction with Mutual Proximity.

### Class Inheritance Diagram

digraph inheritance9fd1b27e05 { rankdir=LR; size="8.0, 12.0"; "LocalScaling" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Hubness reduction with local scaling."]; "MutualProximity" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Hubness reduction with Mutual Proximity."]; "NoHubnessReduction" [fontname="Vera Sans, DejaVu Sans, Liberation Sans, Arial, Helvetica, sans",fontsize=10,height=0.25,shape=box,style="setlinewidth(0.5)",tooltip="Dummy class to test the library"]; }